@@ -3,6 +3,10 @@
 /* Contact: tobias@fomalhaut.de */
 /* Updated to version 1.0.0 by Alan Fitch, apfitch@ieee.org */
 /* Version 1.1.0 - fixed bug in TokenOK, fps can be set to 12 */
+/* Version 1.2.0 - Added non-cumulative track lengths feature */
+/*               - 75 fps option for CD track splitting       */
+/*               - check for ascending order split points */
+/* Version 1.2.1 - frames may be set to 0 - test is >= 0 rather >0 */
 #include "wavsplit.h"
 
 int main (int argc, char *argv[])
@@ -12,17 +16,19 @@ int main (int argc, char *argv[])
   char *strtokPtr;
 
   static struct option long_options[] = {
-    {OPF_QUIET_LONG, no_argument, 0, OPF_QUIET},
-    {OPF_HELP_LONG, no_argument, 0, OPF_HELP},
-    {OPF_HOURS_LONG, no_argument, 0, OPF_HOURS},
-    {OPF_SECONDS_LONG, no_argument, 0, OPF_SECONDS},
-    {OPF_FRAMES_LONG, required_argument, 0, OPF_FRAMES},
+    {OPF_QUIET_LONG, no_argument, 0, (int) OPF_QUIET},
+    {OPF_HELP_LONG, no_argument, 0, (int) OPF_HELP},
+    {OPF_HOURS_LONG, no_argument, 0, (int) OPF_HOURS},
+    {OPF_SECONDS_LONG, no_argument, 0, (int) OPF_SECONDS},
+    {OPF_FRAMES_LONG, required_argument, 0, (int) OPF_FRAMES},
+    {OPF_TRACK_LONG, no_argument, 0, (int) OPF_TRACK},
     {0, 0, 0, 0}
   };
 
-  unsigned int UseHours, UseFrames, UseSeconds, fps;
+  unsigned int UseHours, UseFrames, UseSeconds, fps, UseTrackLens;
   char cmdopts[] =
-    { OPF_QUIET, OPF_HELP, OPF_HOURS, OPF_SECONDS, OPF_FRAMES, ':' };
+    { OPF_QUIET, OPF_HELP, OPF_HOURS, OPF_SECONDS, OPF_FRAMES, ':',
+OPF_TRACK };
 
   timepos splitpos[argc - 1];
 
@@ -31,13 +37,16 @@ int main (int argc, char *argv[])
   UseFrames = DEFAULT_FRAMES;
   UseSeconds = DEFAULT_SECONDS;
   fps = DEFAULT_FPS;
+  UseTrackLens = DEFAULT_TRACK;
 
-  if (verbose) {
+  if (verbose == 1) {
     printf ("\nWAVSPLIT version %s (http://www.fomalhaut.de)\n", VERSION);
     printf ("Licensed under GPL by author Tobias Weihmann\n");
     printf ("Hour patch by Sacha Bartok (sacha@myrealbox.com)\n");
     printf
-      ("Modified for frames, hours, seconds, decimal seconds by Alan Fitch\n\n");
+      ("Modified for frames, hours, seconds, decimal seconds by Alan Fitch\n");
+    printf
+      ("Modified for individual track lengths (non-cumulative splits) by Derek Schuff\n\n");
   }
   while ((optch = getopt_long (argc, argv, cmdopts, long_options,
                                &option_index)) != -1) {
@@ -62,17 +71,21 @@ int main (int argc, char *argv[])
       UseFrames = 1;
       Report ("Frames options selected", "INFO", verbose);
       if (optarg) {
-        fps = atoi (optarg);
-        if (!checkfps (fps)) {
-          Report ("Frames argument must be 12, 24, 25, or 30", "ERROR",
+        fps = (unsigned) atoi (optarg);
+        if (checkfps (fps) == 0) {
+          Report ("Frames argument must be 12, 24, 25, 30, or 75", "ERROR",
                   verbose);
         }
       }
       else {
-        Report ("Missing argument to frames option 12, 24, 25, or 30 fps",
+        Report ("Missing argument to frames option 12, 24, 25, 30, or 75 fps",
                 "ERROR", verbose);
       }
       break;
+    case OPF_TRACK:
+      UseTrackLens = 1;
+      Report ("Non-cumulative track lengths selected", "INFO", verbose);
+      break;
     default:
       usage ();
       return 1;
@@ -91,6 +104,7 @@ int main (int argc, char *argv[])
 
   strcpy (ifile, argv[optind]);
   strcpy (basename, ifile);
+  printf ("%s ", basename);
   if (strcmp (basename + strlen (basename) - 4, ".wav") == 0 ||
       strcmp (basename + strlen (basename) - 4, ".WAV") == 0)
     basename[strlen (basename) - 4] = '\0';
@@ -102,11 +116,11 @@ int main (int argc, char *argv[])
     splitpos[i].seki = 0;
     splitpos[i].frames = 0;
 
-    if (UseSeconds) {
-      if (UseFrames) {
+    if (UseSeconds == 1) {
+      if (UseFrames == 1) {
         strtokPtr = strtok (argv[optind + 1 + i], ":");
         splitpos[i].seki = atoi (strtokPtr);
-        if (!TokenOK ("Frame Counter", &strtokPtr))
+        if (TokenOK ("Frame Counter", &strtokPtr) == 0)
           return 1;
         splitpos[i].frames = atof (strtokPtr);
       }
@@ -116,9 +130,9 @@ int main (int argc, char *argv[])
     }
     else {                      /* not using seconds */
       strtokPtr = strtok (argv[optind + 1 + i], ":");
-      if (UseHours) {
+      if (UseHours == 1) {
         splitpos[i].hr = atoi (strtokPtr);
-        if (!TokenOK ("Minutes", &strtokPtr))
+        if (TokenOK ("Minutes", &strtokPtr) == 0)
           return 1;
         splitpos[i].min = atoi (strtokPtr);
       }
@@ -126,19 +140,19 @@ int main (int argc, char *argv[])
         splitpos[i].min = atoi (strtokPtr);
       }                         /* end if usehours */
 
-      if (UseFrames) {
+      if (UseFrames == 1) {
         /* expect integer seconds followed by floating point frames */
-        if (!TokenOK ("Seconds", &strtokPtr))
+        if (TokenOK ("Seconds", &strtokPtr) == 0)
           return 1;
         splitpos[i].seki = atoi (strtokPtr);
 
-        if (!TokenOK ("Frame Counter", &strtokPtr))
+        if (TokenOK ("Frame Counter", &strtokPtr) == 0)
           return 1;
         splitpos[i].frames = atof (strtokPtr);
       }                         /* not useframe */
       else {
         /* expect floating point seconds and no frames */
-        if (!TokenOK ("Seconds", &strtokPtr))
+        if (TokenOK ("Seconds", &strtokPtr) == 0)
           return 1;
 
         splitpos[i].sek = atof (strtokPtr);
@@ -146,21 +160,23 @@ int main (int argc, char *argv[])
     }                           /* end if useseconds */
 
     /* Check that values are valid */
-    if (UseFrames) {
-      if (!((splitpos[i].frames > 0.0) && (splitpos[i].frames < (float) fps))) {
+    if (UseFrames == 1) {
+      if (((splitpos[i].frames >= 0.0)
+           && (splitpos[i].frames < (float) fps)) == 0) {
         Report
           ("When using frames, value must be >= 0.0  and < Frames Per Second",
            "ERROR", verbose);
       }
     }
-    if (!UseSeconds) {
-      if (!((splitpos[i].sek >= 0.0) && (splitpos[i].sek < 60.0))) {
+    if (UseSeconds == 0) {
+      if (((splitpos[i].sek >= 0.0) && (splitpos[i].sek < 60.0)) == 0) {
         Report ("Seconds must be >= 0.0  and < 60.0", "ERROR", verbose);
       }
-      if (!((splitpos[i].seki >= 0) && (splitpos[i].seki < 60))) {
+      if (((splitpos[i].seki >= 0) && (splitpos[i].seki < 60)) == 0) {
         Report ("Seconds must be >= 0  and < 60", "ERROR", verbose);
       }
-      if (UseHours && !((splitpos[i].min >= 0) && (splitpos[i].min < 60))) {
+      if (UseHours == 1
+          && ((splitpos[i].min >= 0) && (splitpos[i].min < 60)) == 0) {
         Report ("When using Hours, minutes must be >= 0  and < 60", "ERROR",
                 verbose);
       }
@@ -186,7 +202,7 @@ int main (int argc, char *argv[])
   }
   if (readheader () > 0)
     return 1;
-  if (split (UseHours, UseFrames, fps, splits, splitpos) > 0)
+  if (split (UseHours, UseFrames, fps, UseTrackLens, splits, splitpos) > 0)
     return 1;
   close (ifd);
 
@@ -203,10 +219,13 @@ void usage ()
   printf ("\t\t\t\twavsplit [options] wavfile hr:min:sec [hr:min:sec]...\n");
   printf ("\t-%c\t--%s FPS\tuse Frames\n", OPF_FRAMES, OPF_FRAMES_LONG);
   printf
-    ("\t\t\t\tFPS (frames per second) must be either 12, 24, 25, or 30\n");
+    ("\t\t\t\tFPS (frames per second) must be either 12, 24, 25, 30, or 75\n");
   printf ("\t\t\t\twavsplit [options] wavfile min:sec:fr [min:sec:fr]...\n");
   printf ("\t-%c\t--%s\tUse Seconds\n", OPF_SECONDS, OPF_SECONDS_LONG);
   printf ("\t\t\t\twavsplit [options] wavfile sec [sec]...\n");
+  printf
+    ("\t-%c\t--%s\tUse individual track times (instead of cumulative split times)\n",
+     OPF_TRACK, OPF_TRACK_LONG);
   printf ("\t-%c\t--%s\t\tThis info\n", OPF_HELP, OPF_HELP_LONG);
   printf ("\nYou can combine both Hours and frames options\n");
   printf ("\nExamples:\n");
@@ -239,13 +258,15 @@ int TokenOK (const char *Message, char **strPtr)
   return 1;
 }
 
-int checkfps (unsigned int fps)
+unsigned int checkfps (unsigned int fps)
 {
-  return (fps == 12) || (fps == 24) || (fps == 25) || (fps == 30);
+  return (fps == 12) || (fps == 24) || (fps == 25) || (fps == 30)
+    || (fps == 75);
 }
 
 int split (unsigned int UseHours, unsigned int UseFrames,
-           unsigned int fps, int splits, timepos * split)
+           unsigned int fps, unsigned int UseTrackLens, int splits,
+           timepos * split)
 {
   char *buf, *bp_out;
   long to_write, to_read, n_read, pos;
@@ -268,7 +289,7 @@ int split (unsigned int UseHours, unsigned int UseFrames,
   /* if (verbose) printf("Allocated %ld bytes for buffer.\n", in_blk_size+1); */
 
   /* Erste Datei ffnen */
-  to_write = calcsplit (UseHours, UseFrames, fps, fnr, split);
+  to_write = calcsplit (UseHours, UseFrames, fps, UseTrackLens, fnr, split);
   pos = to_write;
   if (createout (fnr + 1, to_write) > 0)
     return 1;
@@ -301,7 +322,9 @@ int split (unsigned int UseHours, unsigned int UseFrames,
         to_read -= to_write;
 
         if (++fnr < splits) {
-          to_write = calcsplit (UseHours, UseFrames, fps, fnr, split) - pos;
+          to_write =
+            calcsplit (UseHours, UseFrames, fps, UseTrackLens, fnr,
+                       split) - pos;
         }
         else {
           to_write = databytes - pos;
@@ -495,9 +518,14 @@ UseHours = 1, UseFrames =1:
 
 */
 long calcsplit (unsigned int UseHours, unsigned int UseFrames,
-                unsigned int fps, int splitnr, timepos * split)
+                unsigned int fps, unsigned int UseTrackLens,
+                int splitnr, timepos * split)
 {
+  static double CumulativeTime = 0.0;   /* Static variable to accumulate time for track length mode */
+  static double LastSplitTimeFloat = 0.0;       /* Allows check for ascending split times */
+
   double TimeFloat = 0.0;
+  double SplitTimeFloat = 0.0;
   long pos;
   unsigned int Opt = 2 * UseHours + UseFrames;
 
@@ -524,14 +552,34 @@ long calcsplit (unsigned int UseHours, unsigned int UseFrames,
     break;
   }
 
+  /* Accumulate track lengths if necessary. */
+  if (UseTrackLens) {
+    CumulativeTime = CumulativeTime + TimeFloat;
+    SplitTimeFloat = CumulativeTime;
+  }
+  else
+    SplitTimeFloat = TimeFloat;
+
+  /* Check for ascending split times */
+  if (SplitTimeFloat <= LastSplitTimeFloat)
+    Report ("Split times must be in ascending order", "ERROR", verbose);
+  /* Remember last split time so check can be carried out next time */
+  LastSplitTimeFloat = SplitTimeFloat;
+
   /* first calculate to the nearest sample, then scale by the  */
   /* block size to avoid getting e.g. half a block */
 
-  pos = (long) ((TimeFloat * (double) waveformat.dwSamplesPerSec));
+  pos = (long) ((SplitTimeFloat * (double) waveformat.dwSamplesPerSec));
   pos = pos * waveformat.wBlockAlign;
 
-  if (verbose)
-    printf ("[%02d]\tuntil %5d ", splitnr + 1, split[splitnr].hr);
+  if (verbose) {
+    if (UseTrackLens) {
+      printf ("[%02d]\tlength%5d ", splitnr + 1, split[splitnr].hr);
+    }
+    else {
+      printf ("[%02d]\tuntil %5d ", splitnr + 1, split[splitnr].hr);
+    }
+  }
   if (UseFrames)
     printf ("%5d  %8.3f  %12ld    %3.2f%%\n",
             split[splitnr].min,
