@@ -15,7 +15,7 @@
 #include <string.h>
 #include <assert.h>
 
-#define VERSION "1.1.0"
+#define VERSION "1.2.1"
 #define MAX_PATH 255
 #define BUFFERSIZE 65536
 #define PCM_WAVE_FORMAT  1
@@ -25,17 +25,19 @@
 #define DEFAULT_FRAMES 0
 #define DEFAULT_FPS 25
 #define DEFAULT_SECONDS 0
+#define DEFAULT_TRACK 0
 #define OPF_QUIET 'q'
 #define OPF_HELP 'h'
 #define OPF_HOURS 'H'
 #define OPF_FRAMES 'f'
 #define OPF_SECONDS 's'
+#define OPF_TRACK 't'
 #define OPF_QUIET_LONG "quiet"
 #define OPF_HELP_LONG "help"
 #define OPF_HOURS_LONG "Hours"
 #define OPF_FRAMES_LONG "frames"
 #define OPF_SECONDS_LONG "seconds"
-
+#define OPF_TRACK_LONG "tracktimes"
 
 typedef enum {
   USE_HOURS,
@@ -111,33 +113,33 @@ static __inline__ short _LE_short (unsigned char *lp)
 
 #endif
 
-char *findchunk ();
-int readheader ();
-void Report(const char * Message, const char * Severity, int Verbose);
-int TokenOK (const char *Message, char **strPtr);
-int checkfps (unsigned int fps);
-int split (unsigned int UseHours, unsigned int UseFrames,
-           unsigned int fps,
-           int splits, timepos * splitpos);
-long calcsplit (unsigned int UseHours, unsigned int UseFrames,
-                unsigned int fps,
-                int splitnr, timepos * split);
-int createout ();
+static char *findchunk ();
+static int readheader ();
+static void Report (const char *Message, const char *Severity, int Verbose);
+static int TokenOK (const char *Message, char **strPtr);
+static unsigned int checkfps (unsigned int fps);
+static int split (unsigned int UseHours, unsigned int UseFrames,
+                  unsigned int fps, unsigned int UseTrackLens,
+                  int splits, timepos * splitpos);
+static long calcsplit (unsigned int UseHours, unsigned int UseFrames,
+                       unsigned int fps, unsigned int UseTrackLens,
+                       int splitnr, timepos * split);
+static int createout ();
 int closeout ();
 void display (unsigned char avgleft, unsigned char avgright,
               unsigned char avgloud);
-void usage ();
-long stdread (char *buf, long nchars);
+static void usage ();
+static long stdread (char *buf, long nchars);
 #ifdef __powerpc__
 static _ConvertHeaderFromNative (WAVE_HEADER * hdr);
 static _ConvertHeaderToNative (WAVE_HEADER * hdr);
 #endif
 
-char *ptr;
-WAVEFORMAT waveformat;
-u_long databytes, b;
-int ifd, ofd;
-int verbose;
-char basename[MAX_PATH + 1], ifile[MAX_PATH + 1];
+static char *ptr;
+static WAVEFORMAT waveformat;
+static u_long databytes, b;
+static int ifd, ofd;
+static int verbose;
+static char basename[MAX_PATH + 1], ifile[MAX_PATH + 1];
 
 #endif
